@@ -1,20 +1,62 @@
+#' Create a document similarity network
+#'
+#' This function can be used to structure the output of the \link[RNewsflow]{compare_documents} function as an igraph network.
+#'
+#' @param el  An RNewsflow_edgelist object, as created with \link[RNewsflow]{compare_documents}.
+#'
+#' @return A network/graph in the \link[igraph]{igraph} class
+#' @export
+#'
+#' @examples
+#' rnewsflow_dfm 
+#' 
+#' dtm = quanteda::dfm_tfidf(rnewsflow_dfm)
+#' el = compare_documents(dtm, date_var='date', hour_window = c(0.1, 36))
+#' 
+#' g = as_document_network(el)
+#' g
+as_document_network <- function(el){
+  el = as_rnewsflow_edgelist(el)
+  
+  g = igraph::graph.data.frame(el$d[,c('from','to')])
+  e_attr = setdiff(colnames(el$d), c('from','to'))
+  for (attrib in e_attr) {
+    g = igraph::set_edge_attr(g, attrib, value = el$d[[attrib]])
+  }
+  if (nrow(el$d) > 0)
+    if (!all(igraph::V(g)$name %in% c(el$from_meta$document_id, el$to_meta$document_id))) stop("Not all documents in d match with an 'id' in the meta information")
+  
+  meta = merge(el$from_meta, el$to_meta, by = intersect(colnames(el$from_meta), colnames(el$to_meta)), all = T)
+  ## add documents in meta data.frame that do not appear in the edgelist (in other words, isolates)
+  missingmeta = as.character(meta$document_id[!meta$document_id %in% igraph::V(g)$name])
+  g = igraph::add.vertices(g, nv = length(missingmeta), attr = list(name=missingmeta))
+  
+  meta = meta[list(igraph::V(g)$name),,on='document_id']
+  m_attr = setdiff(colnames(meta), 'document_id')
+  for(attrib in m_attr){
+    g = igraph::set.vertex.attribute(g, attrib, value= if (is.numeric(meta[[attrib]])) meta[[attrib]] else as.character(meta[[attrib]]))
+  }
+  
+  g
+}
+
 #' Create a document similarity network
 #'
 #' Combines document similarity data (d) with document meta data (meta) into an \link[igraph]{igraph} network/graph.
 #' 
-#' This function is mainly offered to mimic the output of the \link[RNewsflow]{newsflow.compare} function when using imported document similarity data.
+#' This function is mainly offered to mimic the output of the \link[RNewsflow]{as_document_network} function when using imported document similarity data.
 #' This way the functions for transforming, aggregating and visualizing the document similarity data can be used.
 #'
-#' @param d A data.frame with three columns, that represents an edgelist with weight values. 
-#' The first and second column represent the names/ids of the 'from' and 'to' documents/vertices. 
-#' The third column represents the similarity score. Column names are ignored
-#' @param meta A data.frame where rows are documents and columns are document meta information. 
-#' Should at least contain 2 columns: the document name/id and date. 
-#' The name/id column should match the document names/ids of the edgelist, and its label is specified in the `id.var` argument. 
-#' The date column should be intepretable with \link[base]{as.POSIXct}, and its label is specified in the `date.var` argument.            
-#' @param id.var The label for the document name/id column in the `meta` data.frame. Default is "document_id"
-#' @param date.var The label for the document date column in the `meta` data.frame . default is "date"
-#' @param min.similarity For convenience, ignore all edges where the weight is below `min.similarity`. 
+#' @param d              A data.frame with three columns, that represents an edgelist with weight values. 
+#'                       The first and second column represent the names/ids of the 'from' and 'to' documents/vertices. 
+#'                       The third column represents the similarity score. Column names are ignored
+#' @param meta           A data.frame where rows are documents and columns are document meta information. 
+#'                       Should at least contain 2 columns: the document name/id and date. 
+#'                       The name/id column should match the document names/ids of the edgelist, and its label is specified in the `id_var` argument. 
+#'                       The date column should be intepretable with \link[base]{as.POSIXct}, and its label is specified in the `date_var` argument.            
+#' @param id_var         The label for the document name/id column in the `meta` data.frame. Default is "document_id"
+#' @param date_var       The label for the document date column in the `meta` data.frame . default is "date"
+#' @param min_similarity For convenience, ignore all edges where the weight is below `min_similarity`. 
 #'
 #' @return A network/graph in the \link[igraph]{igraph} class
 #' @export
@@ -33,34 +75,34 @@
 #' 
 #' igraph::get.data.frame(g, 'both')
 #' igraph::plot.igraph(g)
-document.network <- function(d, meta, id.var='document_id', date.var='date', min.similarity=NA){
-  if (!date.var %in% colnames(meta)) stop('The name specified in date.var is not a column in meta')
-  if (!id.var %in% colnames(meta)) stop('The name specified in id.var is not a column in meta')
+create_document_network <- function(d, meta, id_var='document_id', date_var='date', min_similarity=NA){
+  if (!date_var %in% colnames(meta)) stop('The name specified in date_var is not a column in meta')
+  if (!id_var %in% colnames(meta)) stop('The name specified in id_var is not a column in meta')
   
   if (nrow(d) == 0) d = data.frame(x=numeric(), y=numeric(), similarity=numeric())
   
   colnames(d) = c('x','y','similarity')
   
-  if (!is.na(min.similarity)) d = d[d$similarity >= min.similarity, c('x','y','similarity')]
+  if (!is.na(min_similarity)) d = d[d$similarity >= min_similarity, c('x','y','similarity')]
   if (is.data.table(d)) {
     d = data.table::setorderv(d, cols='similarity', order = -1)
   } else {
     d = d[order(-d$similarity),]
   }
-
+  
   g = igraph::graph.data.frame(d[,c('x','y')])
   igraph::E(g)$weight = d$similarity
   if (nrow(d) > 0)
-    if (!all(igraph::V(g)$name %in% meta[[id.var]])) stop("Not all documents in d match with an 'id' in the meta information")
+    if (!all(igraph::V(g)$name %in% meta[[id_var]])) stop("Not all documents in d match with an 'id' in the meta information")
   
   ## add documents in meta data.frame that do not appear in the edgelist (in other words, isolates)
-  missingmeta = as.character(meta[!meta[,id.var] %in% igraph::V(g)$name, id.var])
+  missingmeta = as.character(meta[!meta[,id_var] %in% igraph::V(g)$name, id_var])
   g = igraph::add.vertices(g, nv = length(missingmeta), attr = list(name=missingmeta))
   
-  meta = meta[match(igraph::V(g)$name, meta[,id.var]),]
-  attribs = colnames(meta)[!colnames(meta) == id.var]
+  meta = meta[match(igraph::V(g)$name, meta[,id_var]),]
+  attribs = colnames(meta)[!colnames(meta) == id_var]
   for(attrib in attribs){
-    g = igraph::set.vertex.attribute(g, attrib, value=as.character(meta[,attrib]))
+    g = igraph::set.vertex.attribute(g, attrib, value= if (is.numeric(meta[[attrib]])) meta[[attrib]] else as.character(meta[[attrib]]))
   }
   
   edgelist = igraph::get.edges(g, igraph::E(g))
@@ -71,20 +113,22 @@ document.network <- function(d, meta, id.var='document_id', date.var='date', min
   g
 }
 
+
+
 #' Visualize (a subcomponent) of the document similarity network 
 #'
-#' @param g A document similarity network, as created with \link[RNewsflow]{newsflow.compare} or \link[RNewsflow]{document.network}
-#' @param date.attribute The label of the vertex/document date attribute. Default is "date"
-#' @param source.attribute The label of the vertex/document source attribute. Default is "source"
-#' @param subcomp_i Optional. If an integer is given, the network is decomposed into subcomponents (i.e. unconnected components) and only the i-th component is visualized.
-#' @param dtm Optional. If a document-term matrix that contains the documents in g is given, a wordcloud with the most common words of the network is added. 
-#' @param sources Optional. Use a character vector to select only certain sources
-#' @param only.outer.date If TRUE, only the labels for the first and last date are reported on the x-axis
-#' @param date.format The date format of the date labels (see \link[base]{format.POSIXct})
-#' @param margins The margins of the network plot. The four values represent bottom, left, top and right margin. 
-#' @param isolate.color Optional. Set a custom color for isolates
-#' @param source.loops If set to FALSE, all edges between vertices/documents of the same source are ignored.
-#' @param ... Additional arguments for the network plotting function \link[igraph]{plot.igraph} 
+#' @param g                 A document similarity network, as created with \link[RNewsflow]{newsflow.compare} or \link[RNewsflow]{document.network}
+#' @param date_attribute    The label of the vertex/document date attribute. Default is "date"
+#' @param source_attribute  The label of the vertex/document source attribute. Default is "source"
+#' @param subcomp_i         Optional. If an integer is given, the network is decomposed into subcomponents (i.e. unconnected components) and only the i-th component is visualized.
+#' @param dtm               Optional. If a document-term matrix that contains the documents in g is given, a wordcloud with the most common words of the network is added. 
+#' @param sources           Optional. Use a character vector to select only certain sources
+#' @param only_outer_date   If TRUE, only the labels for the first and last date are reported on the x-axis
+#' @param date_format       The date format of the date labels (see \link[base]{format.POSIXct})
+#' @param margins           The margins of the network plot. The four values represent bottom, left, top and right margin. 
+#' @param isolate_color     Optional. Set a custom color for isolates
+#' @param source_loops      If set to FALSE, all edges between vertices/documents of the same source are ignored.
+#' @param ...               Additional arguments for the network plotting function \link[igraph]{plot.igraph} 
 #'
 #' @return Nothing. 
 #' @export
@@ -96,16 +140,16 @@ document.network <- function(d, meta, id.var='document_id', date.var='date', min
 #' docnet_comps = igraph::decompose.graph(docnet) # get subcomponents
 #' 
 #' # subcomponent 1
-#' document.network.plot(docnet_comps[[1]]) 
+#' document_network_plot(docnet_comps[[1]]) 
 #' 
 #' # subcomponent 2 with wordcloud
-#' document.network.plot(docnet_comps[[2]], dtm=dtm) 
+#' document_network_plot(docnet_comps[[2]], dtm=dtm) 
 #' 
 #' # subcomponent 3 with additional arguments passed to plot.igraph 
-#' document.network.plot(docnet_comps[[3]], dtm=dtm, vertex.color='red') 
-document.network.plot <- function(g, date.attribute='date', source.attribute='source', subcomp_i=NULL, dtm=NULL, sources=NULL, only.outer.date=FALSE, date.format='%Y-%m-%d %H:%M', margins=c(5,8,1,13), isolate.color=NULL, source.loops=TRUE, ...){
-  g = igraph::set.vertex.attribute(g, 'date', value= igraph::get.vertex.attribute(g, date.attribute))
-  g = igraph::set.vertex.attribute(g, 'source', value= igraph::get.vertex.attribute(g, source.attribute))
+#' document_network_plot(docnet_comps[[3]], dtm=dtm, vertex.color='red') 
+document_network_plot <- function(g, date_attribute='date', source_attribute='source', subcomp_i=NULL, dtm=NULL, sources=NULL, only_outer_date=FALSE, date_format='%Y-%m-%d %H:%M', margins=c(5,8,1,13), isolate_color=NULL, source_loops=TRUE, ...){
+  g = igraph::set.vertex.attribute(g, 'date', value= igraph::get.vertex.attribute(g, date_attribute))
+  g = igraph::set.vertex.attribute(g, 'source', value= igraph::get.vertex.attribute(g, source_attribute))
   
   if(is.null(subcomp_i)){
     cluster = g
@@ -129,18 +173,18 @@ document.network.plot <- function(g, date.attribute='date', source.attribute='so
     )
   } 
   
-  plotDocNet(cluster, sources, only.outer.date, date.format, margins, isolate.color=NULL, source.loops=TRUE, ...)
+  plot_doc_net(cluster, sources, only_outer_date, date_format, margins, isolate_color=NULL, source_loops=TRUE, ...)
   if(!is.null(dtm)) graphics::layout(matrix(c(1, 1, 1, 1), 2, 2, byrow = TRUE))
 }
 
-plotDocNet <- function(cluster, sources=NULL, only.outer.date=FALSE, date.format='%Y-%m-%d %H:%M', margins=c(5,8,1,13), isolate.color=NULL, source.loops=TRUE, ...){
+plot_doc_net <- function(cluster, sources=NULL, only_outer_date=FALSE, date_format='%Y-%m-%d %H:%M', margins=c(5,8,1,13), isolate_color=NULL, source_loops=TRUE, ...){
   graphics::par(mar = margins)
   if(is.null(sources)) sources = sort(unique(igraph::V(cluster)$source))
   igraph::E(cluster)$width = scales::rescale(igraph::E(cluster)$weight, c(2,4), from = c(0,1))
   igraph::E(cluster)$arrow.size = 0.45
   igraph::E(cluster)$color = grDevices::grey(scales::rescale(igraph::E(cluster)$weight, c(0.8,0.2), from = c(0,1)))
   
-  if(!source.loops){
+  if(!source_loops){
     edgelist = igraph::get.edgelist(cluster)
     xmatch = match(edgelist[,1], igraph::V(cluster)$name)
     ymatch = match(edgelist[,2], igraph::V(cluster)$name)
@@ -157,7 +201,7 @@ plotDocNet <- function(cluster, sources=NULL, only.outer.date=FALSE, date.format
   if(!'label' %in% vertex.atts) igraph::V(cluster)$label = ''
   if(!'label.color' %in% vertex.atts) igraph::V(cluster)$label.color = 'black'
   
-  if(!is.null(isolate.color)) igraph::V(cluster)$color[igraph::degree(cluster) == 0] = isolate.color
+  if(!is.null(isolate_color)) igraph::V(cluster)$color[igraph::degree(cluster) == 0] = isolate_color
   
   ymin = 1 - max(igraph::V(cluster)$y)*(1/max(igraph::V(cluster)$y))
   cluster$layout = igraph::layout.norm(cbind(as.numeric(igraph::V(cluster)$x), igraph::V(cluster)$y), -1, 1, ymin, 1)
@@ -191,38 +235,38 @@ plotDocNet <- function(cluster, sources=NULL, only.outer.date=FALSE, date.format
   graphics::abline(v=inner_date_i, col="grey10", lty='dotted')
   
   graphics::clip(-2,2,-100,2)
-  outer_date_print = format(as.POSIXct(outer_date), date.format)
-  if(!only.outer.date & length(inner_date) > 0){
+  outer_date_print = format(as.POSIXct(outer_date), date_format)
+  if(!only_outer_date & length(inner_date) > 0){
     graphics::text(x=outer_date_i, y=ymin-0.2, label=outer_date_print, srt=30, adj=1) 
-    inner_date_print = format(as.POSIXct(inner_date), date.format)
+    inner_date_print = format(as.POSIXct(inner_date), date_format)
     graphics::text(x=inner_date_i, y=ymin-0.2, label=inner_date_print, srt=30, adj=1) 
   } else graphics::text(x=outer_date_i, y=ymin-0.2, label=outer_date_print, srt=30, adj=1) 
 }
 
 #' Show time window of document pairs 
 #'
-#' This function aggregates the edges for all combinations of attributes specified in `from.attribute` and `to.attribute`, and shows the minimum and maximum hour difference for each combination.
+#' This function aggregates the edges for all combinations of attributes specified in `from_attribute` and `to_attribute`, and shows the minimum and maximum hour difference for each combination.
 #'
 #' The \link[RNewsflow]{filter.window} function can be used to filter edges that fall outside of the intended time window. 
 #'
 #' @param g A document similarity network, as created with \link[RNewsflow]{newsflow.compare} or \link[RNewsflow]{document.network}  
-#' @param to.attribute The vertex attribute to aggregate the `to` group of the edges
-#' @param from.attribute The vertex attribute to aggregate the `from` group of the edges
+#' @param to_attribute The vertex attribute to aggregate the `to` group of the edges
+#' @param from_attribute The vertex attribute to aggregate the `from` group of the edges
 #'
 #' @return A data.frame showing the left and right edges of the window for each unique group.
 #' @export
 #'
 #' @examples
 #' data(docnet)
-#' show.window(docnet, to.attribute = 'source')
-#' show.window(docnet, to.attribute = 'sourcetype')
-#' show.window(docnet, to.attribute = 'sourcetype', from.attribute = 'sourcetype')
-show.window <- function(g, to.attribute=NULL, from.attribute=NULL){
-  from.vertices = if(is.null(from.attribute)) rep('any document', igraph::vcount(g)) else igraph::get.vertex.attribute(g, from.attribute)
-  to.vertices = if(is.null(to.attribute)) rep('any document', igraph::vcount(g)) else igraph::get.vertex.attribute(g, to.attribute)
+#' show_window(docnet, to_attribute = 'source')
+#' show_window(docnet, to_attribute = 'sourcetype')
+#' show_window(docnet, to_attribute = 'sourcetype', from_attribute = 'sourcetype')
+show_window <- function(g, to_attribute=NULL, from_attribute=NULL){
+  from_vertices = if(is.null(from_attribute)) rep('any document', igraph::vcount(g)) else igraph::get.vertex.attribute(g, from_attribute)
+  to_vertices = if(is.null(to_attribute)) rep('any document', igraph::vcount(g)) else igraph::get.vertex.attribute(g, to_attribute)
   
   e = data.frame(igraph::get.edges(g, igraph::E(g)))
-  medwindow = stats::aggregate(igraph::E(g)$hourdiff, by=list(from=from.vertices[e$X1], to=to.vertices[e$X2]), FUN = function(x) cbind(min(x), max(x)))
+  medwindow = stats::aggregate(igraph::E(g)$hourdiff, by=list(from=from_vertices[e$X1], to=to_vertices[e$X2]), FUN = function(x) cbind(min(x), max(x)))
   d = data.frame(from = medwindow$from, to=medwindow$to, window.left=medwindow$x[,1], window.right=medwindow$x[,2])
   d
 }
@@ -230,43 +274,43 @@ show.window <- function(g, to.attribute=NULL, from.attribute=NULL){
 
 #' Filter edges from the document similarity network based on hour difference
 #'
-#' The `filter.window` function can be used to filter the document pairs (i.e. edges) using the `hour.window` parameter, which works identical to the `hour.window` parameter in the `newsflow.compare` function. 
-#' In addition, the `from.vertices` and `to.vertices` parameters can be used to select the vertices (i.e. documents) for which this filter is applied.
+#' The `filter_window` function can be used to filter the document pairs (i.e. edges) using the `hour_window` parameter, which works identical to the `hour_window` parameter in the `newsflow.compare` function. 
+#' In addition, the `from_vertices` and `to_vertices` parameters can be used to select the vertices (i.e. documents) for which this filter is applied.
 #'
-#' It is recommended to use the \link[RNewsflow]{show.window} function to verify whether the hour windows are correct according to the assumptions and focus of the study.
+#' It is recommended to use the \link[RNewsflow]{show_window} function to verify whether the hour windows are correct according to the assumptions and focus of the study.
 #'
 #' @param g A document similarity network, as created with \link[RNewsflow]{newsflow.compare} or \link[RNewsflow]{document.network}  
-#' @param hour.window A vector of length 2, in which the first and second value determine the left and right side of the window, respectively. For example, c(-10, 36) will compare each document to all documents between the previous 10 and the next 36 hours.
-#' @param to.vertices A filter to select the vertices `to` which an edge is filtered. 
-#' For example, if `V(g)$sourcetype == "newspaper"` is used, then the hour.window filter is only applied for edges `to` newspaper documents (specifically, where the sourcetype attribute is "newspaper"). 
-#' @param from.vertices A filter to select the vertices `from` which an edge is filtered. 
-#' Works identical to `to.vertices`.  
+#' @param hour_window A vector of length 2, in which the first and second value determine the left and right side of the window, respectively. For example, c(-10, 36) will compare each document to all documents between the previous 10 and the next 36 hours.
+#' @param to_vertices A filter to select the vertices `to` which an edge is filtered. 
+#' For example, if `V(g)$sourcetype == "newspaper"` is used, then the hour_window filter is only applied for edges `to` newspaper documents (specifically, where the sourcetype attribute is "newspaper"). 
+#' @param from_vertices A filter to select the vertices `from` which an edge is filtered. 
+#' Works identical to `to_vertices`.  
 #'
 #' @return A network/graph in the \link[igraph]{igraph} class
 #' @export
 #'
 #' @examples
 #' data(docnet)
-#' show.window(docnet, to.attribute = 'source') # before filtering
+#' show_window(docnet, to_attribute = 'source') # before filtering
 #' 
-#' docnet = filter.window(docnet, hour.window = c(0.1,24))
+#' docnet = filter_window(docnet, hour_window = c(0.1,24))
 #' 
-#' docnet = filter.window(docnet, hour.window = c(6,36), 
-#'                        to.vertices = V(docnet)$sourcetype == 'Print NP')
+#' docnet = filter_window(docnet, hour_window = c(6,36), 
+#'                        to_vertices = V(docnet)$sourcetype == 'Print NP')
 #' 
-#' show.window(docnet, to.attribute = 'sourcetype') # after filtering per sourcetype
-#' show.window(docnet, to.attribute = 'source') # after filtering per source
-filter.window <- function(g, hour.window, to.vertices=NULL, from.vertices=NULL){
-  if(is.null(from.vertices)) from.vertices = rep(TRUE, igraph::vcount(g))
-  if(is.null(to.vertices)) to.vertices = rep(TRUE, igraph::vcount(g))
+#' show_window(docnet, to_attribute = 'sourcetype') # after filtering per sourcetype
+#' show_window(docnet, to_attribute = 'source') # after filtering per source
+filter_window <- function(g, hour_window, to_vertices=NULL, from_vertices=NULL){
+  if(is.null(from_vertices)) from_vertices = rep(TRUE, igraph::vcount(g))
+  if(is.null(to_vertices)) to_vertices = rep(TRUE, igraph::vcount(g))
   
   # get vector indicating which edges are selected given the vertex.filter
   from.edge.i = igraph::get.edges(g, igraph::E(g))[,1]
   to.edge.i = igraph::get.edges(g, igraph::E(g))[,2]
-  selected_edge = from.vertices[from.edge.i] & to.vertices[to.edge.i]
+  selected_edge = from_vertices[from.edge.i] & to_vertices[to.edge.i]
   
   # filter the selected edges
-  delete.i = selected_edge & (igraph::E(g)$hourdiff < hour.window[1] | igraph::E(g)$hourdiff > hour.window[2])
+  delete.i = selected_edge & (igraph::E(g)$hourdiff < hour_window[1] | igraph::E(g)$hourdiff > hour_window[2])
   igraph::delete.edges(g, which(delete.i))
 }
 
@@ -287,16 +331,16 @@ filter.window <- function(g, hour.window, to.vertices=NULL, from.vertices=NULL){
 #' data(docnet)
 #' 
 #' subcomp1 = igraph::decompose.graph(docnet)[[2]]
-#' subcomp2 = only.first.match(subcomp1)
+#' subcomp2 = only_first_match(subcomp1)
 #' 
 #' igraph::get.data.frame(subcomp1)
 #' igraph::get.data.frame(subcomp2)
 #' 
 #' graphics::par(mfrow=c(2,1))
-#' document.network.plot(subcomp1, main='All matches')
-#' document.network.plot(subcomp2, main='Only first match')
+#' document_network_plot(subcomp1, main='All matches')
+#' document_network_plot(subcomp2, main='Only first match')
 #' graphics::par(mfrow=c(1,1))
-only.first.match <- function(g){
+only_first_match <- function(g){
   e = data.frame(igraph::get.edges(g, igraph::E(g)))
   
   # first make from and to columns of same temporal order (from before to) by switching columns with negative hourdiff.
@@ -324,7 +368,7 @@ only.first.match <- function(g){
 #' 
 #' The first argument is the network (in the `igraph` class). 
 #' The second argument, for the `by` parameter, is a character vector to indicate one or more vertex attributes based on which the edges are aggregated.
-#' Optionally, the `by` parameter can also be specified separately for `by.from` and `by.to`. 
+#' Optionally, the `by` parameter can also be specified separately for `by_from` and `by_to`. 
 #' 
 #' By default, the function returns the aggregated network as an \link[igraph]{igraph} class.
 #' The edges in the aggregated network have five standard attributes. 
@@ -334,72 +378,72 @@ only.first.match <- function(g){
 #' The `to.V` and `to.Vprop` attributes show the same for the `to` group.
 #' 
 #' In addition, one of the edge attributes of the original network can be aggregated with a given function.
-#' These are specified in the `edge.attribute` and `agg.FUN` parameters.
+#' These are specified in the `edge_attribute` and `agg_FUN` parameters.
 #'
 #' @param g A network/graph in the \link[igraph]{igraph} class
 #' @param by A character string indicating the vertex attributes by which the edges will be aggregated. 
-#' @param by.from Optionally, specify different vertex attributes to aggregate the `from` side of edges 
-#' @param by.to Optionally, specify different vertex attributes to aggregate the `to` side of edges 
-#' @param edge.attribute Select an edge attribute to aggregate using the function specified in `agg.FUN`. Defaults to 'weight'
-#' @param agg.FUN The function used to aggregate the edge attribute
-#' @param return.df Optional. If TRUE, the results are returned as a data.frame. This can in particular be convenient if by.from and by.to are used.
+#' @param by_from Optionally, specify different vertex attributes to aggregate the `from` side of edges 
+#' @param by_to Optionally, specify different vertex attributes to aggregate the `to` side of edges 
+#' @param edge_attribute Select an edge attribute to aggregate using the function specified in `agg_FUN`. Defaults to 'weight'
+#' @param agg_FUN The function used to aggregate the edge attribute
+#' @param return_df Optional. If TRUE, the results are returned as a data.frame. This can in particular be convenient if by_from and by_to are used.
 #' @param keep_isolates if True, also return scores for isolates
 #'
-#' @return A network/graph in the \link[igraph]{igraph} class, or a data.frame if return.df is TRUE.
+#' @return A network/graph in the \link[igraph]{igraph} class, or a data.frame if return_df is TRUE.
 #' @export
 #'
 #' @import data.table
 #'
 #' @examples
 #' data(docnet)
-#' aggdocnet = network.aggregate(docnet, by='sourcetype')
+#' aggdocnet = network_aggregate(docnet, by='sourcetype')
 #' igraph::get.data.frame(aggdocnet, 'both')
 #' 
-#' aggdocdf = network.aggregate(docnet, by.from='sourcetype', by.to='source', return.df = TRUE)
+#' aggdocdf = network_aggregate(docnet, by_from='sourcetype', by_to='source', return_df = TRUE)
 #' head(aggdocdf)
-network.aggregate <- function(g, by=NULL, by.from=by, by.to=by, edge.attribute='weight', agg.FUN=mean, return.df=FALSE, keep_isolates=T){
+network_aggregate <- function(g, by=NULL, by_from=by, by_to=by, edge_attribute='weight', agg_FUN=mean, return_df=FALSE, keep_isolates=T){
   igraph::V(g)$any_vertex = '---'
-  if(is.null(by.from)) by.from = 'any_vertex'
-  if(is.null(by.to)) by.to = 'any_vertex'
+  if(is.null(by_from)) by_from = 'any_vertex'
+  if(is.null(by_to)) by_to = 'any_vertex'
   
   e = data.frame(igraph::get.edges(g, igraph::E(g)))
   v = igraph::get.data.frame(g, 'vertices')  
 
-  e = cbind(e, v[e$X1, by.from, drop=FALSE])
-  e = cbind(e, v[e$X2, by.to, drop=FALSE])
-  colnames(e) = c('from','to', paste('from', by.from, sep='.'), paste('to', by.to, sep='.'))
+  e = cbind(e, v[e$X1, by_from, drop=FALSE])
+  e = cbind(e, v[e$X2, by_to, drop=FALSE])
+  colnames(e) = c('from','to', paste('from', by_from, sep='.'), paste('to', by_to, sep='.'))
   aggvars = colnames(e)[3:ncol(e)]
   
   e$from_unique_match = as.numeric(!duplicated(e[,colnames(e)[-2]]))
   e$to_unique_match = as.numeric(!duplicated(e[,colnames(e)[-1]]))
-  e$var = igraph::get.edge.attribute(g, edge.attribute)
+  e$var = igraph::get.edge.attribute(g, edge_attribute)
   
   e = data.table::setDT(e)
   e = e[, list(edges=.N,
-               edge.attribute=agg.FUN(get('var')), # note that get('var') is used because the CRAN check would otherwise wrongfully interpret 'var' as a global variable (yielding a NOTE)  
+               edge_attribute=agg_FUN(get('var')), # note that get('var') is used because the CRAN check would otherwise wrongfully interpret 'var' as a global variable (yielding a NOTE)  
                from.V=sum(get('from_unique_match')),
                to.V=sum(get('to_unique_match'))),
                by= eval(paste(aggvars, collapse=','))]
   e = as.data.frame(e)
   
-  colnames(e)[colnames(e) == 'edge.attribute'] = paste('agg',edge.attribute, sep='.')
+  colnames(e)[colnames(e) == 'edge_attribute'] = paste('agg',edge_attribute, sep='.')
   
   # match total vertices
   v = data.table::setDT(v)
-  from.totals = v[, list(from.N=.N), by= eval(paste(by.from, collapse=','))]
-  to.totals = v[, list(to.N=.N), by= eval(paste(by.to, collapse=','))]
+  from.totals = v[, list(from.N=.N), by= eval(paste(by_from, collapse=','))]
+  to.totals = v[, list(to.N=.N), by= eval(paste(by_to, collapse=','))]
   
-  e = merge(e, from.totals, by.x=paste('from', by.from, sep='.'), by.y=by.from, all.x=TRUE)
-  e = merge(e, to.totals, by.x=paste('to', by.to, sep='.'), by.y=by.to, all.x=TRUE)
+  e = merge(e, from.totals, by.x=paste('from', by_from, sep='.'), by.y=by_from, all.x=TRUE)
+  e = merge(e, to.totals, by.x=paste('to', by_to, sep='.'), by.y=by_to, all.x=TRUE)
   e$from.Vprop = e$from.V / e$from.N
   e$to.Vprop = e$to.V / e$to.N
   
-  if(!return.df) {
-    e = return.network.aggregate(e, from.totals, to.totals, keep_isolates)
+  if(!return_df) {
+    e = return_network_aggregate(e, from.totals, to.totals, keep_isolates)
     if('any_vertex' %in% names(igraph::vertex.attributes(e))) e = igraph::delete_vertex_attr(e, 'any_vertex')
     return(e)
   }
-  if(return.df) {
+  if(return_df) {
     e = e[,!colnames(e) %in% c('from.N', 'to.N', 'from.any_vertex', 'to.any_vertex')]
     
     edge_col = which(colnames(e) == 'edges') # silly but necessary way to order the from and to attribute columns ()
@@ -408,7 +452,7 @@ network.aggregate <- function(g, by=NULL, by.from=by, by.to=by, edge.attribute='
   }
 }
 
-return.network.aggregate <- function(g.df, from.totals, to.totals, keep_isolates){
+return_network_aggregate <- function(g.df, from.totals, to.totals, keep_isolates){
   vnames = colnames(g.df)[1:(grep('^edges$', colnames(g.df))-1)]
   
   # create network
@@ -487,9 +531,9 @@ graph.plot.presets <- function(g){
 #' It was designed specifically for visualizing aggregated document similarity networks in the RNewsflow package, but works with any network in the \link[igraph]{igraph} class.  
 #'
 #' @param g A network/graph in the \link[igraph]{igraph} class 
-#' @param weight.var The edge attribute that is used to specify the edges
-#' @param weight.thres A threshold for weight. Edges below the threshold are ignored 
-#' @param delete.isolates If TRUE, isolates (i.e. vertices without edges) are ignored.
+#' @param weight_var The edge attribute that is used to specify the edges
+#' @param weight_thres A threshold for weight. Edges below the threshold are ignored 
+#' @param delete_isolates If TRUE, isolates (i.e. vertices without edges) are ignored.
 #' @param vertex.size The size of the verticex/nodes. Defaults to 30. Can be a vector with values per vertex.
 #' @param vertex.color Color of vertices/nodes. Default is lightblue. Can be a vector with values per vertex.
 #' @param vertex.label.color Color of labels for vertices/nodes. Defaults to black. Can be a vector with values per vertex. 
@@ -507,15 +551,15 @@ graph.plot.presets <- function(g){
 #'
 #' @examples
 #' data(docnet)
-#' aggdocnet = network.aggregate(docnet, by='source')
-#' directed.network.plot(aggdocnet, weight.var = 'to.Vprop', weight.thres = 0.2)
-directed.network.plot <- function(g, weight.var='from.Vprop', weight.thres=NULL, delete.isolates=FALSE, 
+#' aggdocnet = network_aggregate(docnet, by='source')
+#' directed_network_plot(aggdocnet, weight_var = 'to.Vprop', weight_thres = 0.2)
+directed_network_plot <- function(g, weight_var='from.Vprop', weight_thres=NULL, delete_isolates=FALSE, 
                                    vertex.size=30, vertex.color='lightblue', vertex.label.color='black', vertex.label.cex=0.7, 
                                    edge.color = 'grey', show.edge.labels=TRUE, edge.label.color = 'black', edge.label.cex = 0.6, edge.arrow.size=1, 
                                    layout=igraph::layout.davidson.harel, ...){
-  igraph::E(g)$weight = igraph::get.edge.attribute(g, weight.var)
-  if(!is.null(weight.thres)) g = igraph::delete.edges(g, which(igraph::E(g)$weight < weight.thres))
-  if(delete.isolates) g = igraph::delete.vertices(g, igraph::degree(g) == 0)
+  igraph::E(g)$weight = igraph::get.edge.attribute(g, weight_var)
+  if(!is.null(weight_thres)) g = igraph::delete.edges(g, which(igraph::E(g)$weight < weight_thres))
+  if(delete_isolates) g = igraph::delete.vertices(g, igraph::degree(g) == 0)
   
   argnames = names(list(...))  
   igraph::E(g)$color = edge.color
