@@ -25,7 +25,7 @@ dtm
 head(docvars(dtm), 3)
 
 ## ------------------------------------------------------------------------
-tdd = term.day.dist(dtm)
+tdd = term_day_dist(dtm)
 tail(tdd, 3)
 
 ## ------------------------------------------------------------------------
@@ -36,96 +36,96 @@ dtm = dtm[,select_terms]
 dtm = quanteda::dfm_tfidf(dtm)
 
 ## ----results='hide', message=FALSE, warning=FALSE------------------------
-g = newsflow.compare(dtm, hour.window = c(0,36), min.similarity = 0.4)
+g = newsflow_compare(dtm, date_var='date',
+                     hour_window = c(0,36), 
+                     min_similarity = 0.4)
 
 ## ------------------------------------------------------------------------
-vertex.sourcetype = V(g)$sourcetype
-edge.hourdiff = E(g)$hourdiff
+vertex_sourcetype = V(g)$sourcetype
+edge_hourdiff = E(g)$hourdiff
 
-head(vertex.sourcetype)
-head(edge.hourdiff)
+head(vertex_sourcetype)
+head(edge_hourdiff)
 
 ## ---- fig.show='hold'----------------------------------------------------
-v = get.data.frame(g, 'vertices')
-e = get.data.frame(g, 'edges')
+v = as_data_frame(g, 'vertices')
+e = as_data_frame(g, 'edges')
 
-head(v,3)
+head(v[,c('name','date','source','sourcetype')],3)
 head(e,3)    
 
 ## ---- fig.width = 7, fig.height = 3--------------------------------------
 hist(E(g)$hourdiff, main='Time distance of document pairs', 
-     xlab = 'Time difference in hours', breaks = 150)
+     xlab = 'Time difference in hours', breaks = 150, right=F)
 
 ## ------------------------------------------------------------------------
 # set window for all vertices
-g = filter.window(g,  hour.window = c(0.1, 36))
+g = filter_window(g,  hour_window = c(0.1, 36))
 
 # set window for print newspapers
-g = filter.window(g,  hour.window = c(6, 36), 
-           to.vertices = V(g)$sourcetype == 'Print NP')
+g = filter_window(g,  hour_window = c(6, 36), 
+           to_vertices = V(g)$sourcetype == 'Print NP')
 
 ## ------------------------------------------------------------------------
-show.window(g, to.attribute = 'source')
+show_window(g, to_attribute = 'source')
 
 ## ------------------------------------------------------------------------
-g_subcomps = decompose.graph(g)
+g_subcomps = decompose(g)
 
 ## ---- fig.width = 7, fig.height = 3--------------------------------------
 gs = g_subcomps[[55]] # select the second sub-component
-document.network.plot(gs)
+document_network_plot(gs)
 
 ## ---- fig.width = 7, fig.height = 4--------------------------------------
-document.network.plot(gs, source.attribute = 'sourcetype', 
+document_network_plot(gs, source_attribute = 'sourcetype', 
                       dtm=dtm)
 
 ## ---- fig.width = 7, fig.height = 3--------------------------------------
-gs_onlyfirst = only.first.match(gs)
-document.network.plot(gs_onlyfirst)
+gs_onlyfirst = only_first_match(gs)
+document_network_plot(gs_onlyfirst)
 
 ## ------------------------------------------------------------------------
-g.agg = network.aggregate(g, by='source', 
-                          edge.attribute='hourdiff', 
-                          agg.FUN=median)
+g_agg = network_aggregate(g, by='source', 
+                          edge_attribute='hourdiff', 
+                          agg_FUN=median)
 
-e = get.data.frame(g.agg, 'edges')
+e = as_data_frame(g_agg, 'edges')
 head(e)
 
 ## ------------------------------------------------------------------------
-adj.m = get.adjacency(g.agg, attr= 'to.Vprop', sparse = FALSE)
-round(adj.m, 2) # round on 2 decimals
+adj_m = as_adjacency_matrix(g_agg, attr= 'to.Vprop', sparse = FALSE)
+round(adj_m, 2) # round on 2 decimals
 
 ## ---- fig.align='center', fig.width=7, fig.height=5----------------------
-directed.network.plot(g.agg, weight.var = 'to.Vprop',
-                       weight.thres = 0.2)
+directed_network_plot(g_agg, weight_var = 'to.Vprop',
+                       weight_thres = 0.2)
 
 ## ---- fig.align='center', fig.width=7, fig.height=5----------------------
-g2 = only.first.match(g)
-g2.agg = network.aggregate(g2, by='source', 
-                           edge.attribute='hourdiff', 
-                           agg.FUN=median)
+g2 = only_first_match(g)
+g2_agg = network_aggregate(g2, by='source', 
+                           edge_attribute='hourdiff', 
+                           agg_FUN=median)
 
-directed.network.plot(g2.agg, weight.var = 'to.Vprop',
-                       weight.thres = 0.2)
+directed_network_plot(g2_agg, weight_var = 'to.Vprop',
+                       weight_thres = 0.2)
 
 ## ------------------------------------------------------------------------
 V(g)$day = format(as.Date(V(g)$date), '%Y-%m-%d')
-agg.perday = network.aggregate(g, 
-              by.from='sourcetype', by.to=c('sourcetype', 'day'), 
-              edge.attribute='hourdiff', agg.FUN=median, 
-              return.df=TRUE)
+agg_perday = network_aggregate(g, 
+              by_from='sourcetype', by_to=c('sourcetype', 'day'), 
+              edge_attribute='hourdiff', agg_FUN=median, 
+              return_df=TRUE)
 
-
-head(agg.perday[agg.perday$to.sourcetype == 'Online NP',  
+head(agg_perday[agg_perday$to.sourcetype == 'Online NP',  
                 c('from.sourcetype', 'to.sourcetype', 'to.day','to.Vprop')])
 
-
 ## ------------------------------------------------------------------------
-agg.perdoc = network.aggregate(g, 
-                  by.from='name', by.to='sourcetype', 
-                  edge.attribute='weight', agg.FUN=max,
-                  return.df=TRUE)
+agg_perdoc = network_aggregate(g, 
+                  by_from='name', by_to='sourcetype', 
+                  edge_attribute='weight', agg_FUN=max,
+                  return_df=TRUE)
 docXsource = xtabs(agg.weight ~ from.name + to.sourcetype, 
-                   agg.perdoc, sparse = FALSE)
+                   agg_perdoc, sparse = FALSE)
 head(docXsource)
 
 ## ----eval=FALSE----------------------------------------------------------
@@ -135,34 +135,33 @@ head(docXsource)
 #  # Prepare DTM
 #  dtm = rnewsflow_dfm  ## copy demo data
 #  
-#  tdd = term.day.dist(dtm)
+#  tdd = term_day_dist(dtm)
 #  dtm = dtm[,tdd$term[tdd$days.entropy.norm <= 0.3]]
 #  
 #  dtm = dfm_tfidf(dtm)
 #  
 #  # Prepare document similarity network
-#  g = newsflow.compare(dtm, hour.window = c(-0.1,60),
-#                       min.similarity = 0.4)
-#  g = filter.window(g, hour.window = c(6, 36),
-#                    to.vertices = V(g)$sourcetype == 'Print NP')
+#  g = newsflow_compare(dtm, hour_window = c(-0.1,60),
+#                       min_similarity = 0.4)
+#  g = filter_window(g, hour_window = c(6, 36),
+#                    to_vertices = V(g)$sourcetype == 'Print NP')
+#  show_window(g, to_attribute = 'source')
 #  
-#  show.window(g, to.attribute = 'source')
+#  g_subcomps = decompose(g)
+#  document_network_plot(g_subcomps[[55]], dtm=dtm)
 #  
-#  g_subcomps = decompose.graph(g)
-#  document.network.plot(g_subcomps[[2]], dtm=dtm)
+#  g_agg = network_aggregate(g, by='source',
+#                            edge_attribute='hourdiff', agg_FUN=median)
 #  
-#  g.agg = network.aggregate(g, by='source',
-#                            edge.attribute='hourdiff', agg.FUN=median)
+#  as_adjacency_matrix(g_agg, attr='to.Vprop')
+#  directed_network_plot(g_agg, weight_var = 'to.Vprop',
+#                        weight_thres=0.2)
 #  
-#  get.adjacency(g.agg, attr='to.Vprop')
-#  directed.network.plot(g.agg, weight.var = 'to.Vprop',
-#                        weight.thres=0.2)
+#  g2 = only_first_match(g)
+#  g2_agg = network_aggregate(g2, by='source',
+#                             edge_attribute='hourdiff', agg_FUN=median)
 #  
-#  g2 = only.first.match(g)
-#  g2.agg = network.aggregate(g2, by='source',
-#                             edge.attribute='hourdiff', agg.FUN=median)
-#  
-#  get.adjacency(g2.agg, attr='to.Vprop')
-#  directed.network.plot(g2.agg, weight.var = 'to.Vprop',
-#                        weight.thres=0.2)
+#  as_adjacency_matrix(g2_agg, attr='to.Vprop')
+#  directed_network_plot(g2_agg, weight_var = 'to.Vprop',
+#                        weight_thres=0.2)
 
