@@ -20,37 +20,52 @@ void as_pct(int i, const SpMat& m, std::vector<double>& res){
 }
 
 
-void as_pnorm(std::vector<double>& res, bool log_trans=false, bool nz = false) {
+void pnorm_filter(std::vector<double>& res, bool log_trans=false, bool nz = false, double max_p=1) {
   NumericVector v = Rcpp::wrap(res);
   if (nz) v = v[v>0];
   if (log_trans) v = log(v+1);
   double M = mean(v);
   double SD = sd(v);
+  double p;
   
   for (int i=0; i < res.size(); i++) {
-    if (SD == 0) {
+    if (SD == 0 || res[i] < M) {
       res[i] = 0;
     } else {
-      //res[i] = (res[i] - M) / SD;
-      res[i] = 1 - R::pnorm(res[i], M, SD, 0, 0);
+      p = R::pnorm(res[i], M, SD, 0, 0);
+      if (p > max_p) res[i] = 0;
     }
   }
 }
 
-void as_pdisparity(std::vector<double>& res) {
+void pbeta_filter(std::vector<double>& res, bool nz = false, double max_p=1) {
+  NumericVector v = Rcpp::wrap(res);
+  if (nz) v = v[v>0];
+  double M = mean(v);
+  double V = var(v);
+  double p;
+
+  double alpha = ((1 - M) / V - 1 / M) * pow(M, 2);
+  double beta  = alpha * (1 / M - 1);
+  
+  for (int i=0; i < res.size(); i++) {
+    p = R::pbeta(res[i], alpha, beta, 0, 0);
+    if (p > max_p) res[i] = 0;
+  }
+}
+
+void pdisparity_filter(std::vector<double>& res, double k, double max_p=1) {
   NumericVector v = Rcpp::wrap(res);
   double vsum = sum(v);
-  double k = sum(v>0);
-  
-  //Rcout << vsum << " " << k << std::endl;
-  
+  double p;
+
   for (int i=0; i < res.size(); i++) {
     if (k == 0) {
       res[i] = 0;
     } else {
-      res[i] = res[i] / vsum;
-      res[i] = pow(1 - res[i], k - 1);
-      res[i] = 1 - res[i];   // inverse for min threshold
+      p = res[i] / vsum;
+      p = pow(1 - p, k - 1);
+      if (p > max_p) res[i] = 0;
     }
   }
 }
@@ -98,3 +113,14 @@ void sim_softprod(int i, const SpMat& m1, const SpMat& m2,
     }
   }
 } 
+
+void sim_lookup(int i, const SpMat& m1, const SpMat& m2, 
+                 std::vector<double>& res, std::vector<bool>& use_pair){
+  // for query lookup in which the value in it2 does not matter
+  for (SpMat::InnerIterator it1(m1,i); it1; ++it1) {
+    for (SpMat::InnerIterator it2(m2,it1.row()); it2; ++it2) {
+      if (!use_pair[it2.row()]) continue;
+      res[it2.row()] += it1.value();
+    }
+  }
+} 
